#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xml-helpers
version:              1.0.0
visibility:           public
id:                   xml-helpers-1.0.0-4qhWXJoUbtX94cToL5WE9g
key:                  xml-helpers-1.0.0-4qhWXJoUbtX94cToL5WE9g
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhusre.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/xml-helpers
synopsis:             Some useful helper functions for the xml library.
description:
    Included are some folds and maps I'\''ve found useful in parsing XML data.

category:             Text, XML
abi:                  8e8b78c36c62c6cc70820a60c3720233
exposed:              True
exposed-modules:      Text.XML.Light.Helpers
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xml-helpers-1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xml-helpers-1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xml-helpers-1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-helpers
hs-libraries:         HSxml-helpers-1.0.0-4qhWXJoUbtX94cToL5WE9g
depends:              base-4.18.2.1 xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
haddock-interfaces:   /usr/share/doc/haskell-xml-helpers/html/xml-helpers.haddock
haddock-html:         /usr/share/doc/haskell-xml-helpers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

